==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/GeoUtils/Tess2Geo/Tess2Geo2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"Tess2Geo.h"

void
GeoGenDet (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoVerQty (Tess, pGeo);
  Tess2GeoEdgeQty (Tess, pGeo);
  Tess2GeoFaceQty (Tess, pGeo);
  Tess2GeoPolyQty (Tess, pGeo);

  return;
}

void
GeoAlloc (struct GEO *pGeo)
{
  /*(*pGeo).VerQty    = 0; */
  /*(*pGeo).DummyVerQty       = 0; */
  /*(*pGeo).EdgeQty   = 0; */
  /*(*pGeo).FaceQty   = 0; */
  /*(*pGeo).PolyQty   = 0; */

  (*pGeo).VerCoo = twoDDoubleDAlloc ((*pGeo).VerQty + 1, 3);
  (*pGeo).VerEdgeQty = oneDDoubleDAlloc_int ((*pGeo).VerQty + 1);
  (*pGeo).VerEdgeNb = twoDIntDAlloc ((*pGeo).VerQty + 1, 20);	/* ? */
  (*pGeo).VerBound = twoDIntDAlloc ((*pGeo).VerQty + 1, 4);
  (*pGeo).VerState = oneDDoubleDAlloc_int ((*pGeo).VerQty + 1);	/* ini to 0 */
  (*pGeo).VerLength = oneDDoubleDAlloc ((*pGeo).VerQty + 1);

  (*pGeo).EdgeVerNb = twoDIntDAlloc ((*pGeo).EdgeQty + 1, 2);
  (*pGeo).EdgeFaceQty = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeFaceNb = twoDIntDAlloc ((*pGeo).EdgeQty + 1, 10);
  (*pGeo).EdgeLength = oneDDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeState = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeDel = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodeQty = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodes = oneDpDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodeCls = oneDpDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNode1Id = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeSeg1Id = oneDDoubleDAlloc_int ((*pGeo).EdgeQty + 1);

  (*pGeo).FaceGerm = twoDIntDAlloc ((*pGeo).FaceQty + 1, 2);
  (*pGeo).FaceVerQty = oneDDoubleDAlloc_int ((*pGeo).FaceQty + 1);
  (*pGeo).FaceVerNb = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEdgeNb = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEdgeOri = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEq = twoDDoubleDAlloc ((*pGeo).FaceQty + 1, 4);
  (*pGeo).FaceState = oneDDoubleDAlloc_int ((*pGeo).FaceQty + 1);
  (*pGeo).FaceDis = oneDDoubleDAlloc_int ((*pGeo).FaceQty + 1);
  (*pGeo).FacePt = oneDDoubleDAlloc_int ((*pGeo).FaceQty + 1);
  (*pGeo).FacePtCoo = twoDDoubleDAlloc ((*pGeo).FaceQty + 1, 3);
  (*pGeo).FaceFF = oneDDoubleDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceBound = oneDDoubleDAlloc_int ((*pGeo).FaceQty + 1);

  (*pGeo).PolyFaceQty = oneDDoubleDAlloc_int ((*pGeo).PolyQty + 1);
  (*pGeo).PolyFaceNb = oneDpIntDAlloc ((*pGeo).PolyQty + 1);
  (*pGeo).PolyFaceOri = oneDpIntDAlloc ((*pGeo).PolyQty + 1);

  (*pGeo).FaceNodes = (NODES*) calloc ((*pGeo).FaceQty + 1, sizeof (NODES));
  (*pGeo).FaceM0D = (MESH*) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));
  (*pGeo).FaceM1D = (MESH*) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));
  (*pGeo).FaceM2D = (MESH*) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));

  (*pGeo).DomainSize = twoDDoubleDAlloc (3, 2);

  return;
}

/* Tess2Geotializing the properties of the vertices */
void
Tess2GeoVer (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoVerCoo (Tess, pGeo);
  Tess2GeoVerEdge (Tess, pGeo);
  Tess2GeoVerBound (Tess, pGeo);
  /* now useless */
  /*Tess2GeoVerState(Tess,pGeo); */

  return;
}

/* Tess2Geotializing the properties of the edges */
void
Tess2GeoEdge (struct TESS Tess, struct GEO *pGeo)
{
  /*LineHeader(-1); printf("Tess2GeoEdgeVerNb\n"); */
  Tess2GeoEdgeVerNb (Tess, pGeo);
  /*LineHeader(-1); printf("Tess2GeoEdgeFace\n"); */
  Tess2GeoEdgeFace (Tess, pGeo);
  /*LineHeader(-1); printf("Tess2GeoEdgeLength\n"); */
  Tess2GeoEdgeLength (pGeo);
  /*printf("Tess2GeoEdgeDel\n"); */
  /*Tess2GeoEdgeDel   (Tess,pGeo); */

  return;
}

/* Tess2Geotializing the properties of the faces */
void
Tess2GeoFace (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoFaceGerm (Tess, pGeo);
  Tess2GeoFaceVer (Tess, pGeo);
  Tess2GeoFaceEdge (Tess, pGeo);
  /*Tess2GeoFaceFF  (Tess,pGeo); */
  Tess2GeoFaceEq (Tess, pGeo);
  Tess2GeoFaceBound (pGeo);
  /* now useless */

  return;
}

/* Tess2Geotializing the properties of the polyhedra */
void
Tess2GeoPoly (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoPolyFace (Tess, pGeo);

  return;
}

/* Tess2GeoDomainSize ini the domain size */
void
Tess2GeoDomainSize (struct TESS Tess, struct GEO *pGeo)
{
  int i, j;
  double **coo = twoDDoubleDAlloc (3, 8);

  for (i = 0; i < 3; i++)
  {
    for (j = 0; j < 8; j++)
      coo[i][j] = Tess.VerCoo[Tess.VerOfDomain[j]][i];

    /* lower bounds are supposed to be 0, 0, 0. */
    (*pGeo).DomainSize[i][0] = oneDDoubleMin (coo[i], 0, 7);
    (*pGeo).DomainSize[i][1] = oneDDoubleMax (coo[i], 0, 7);
  }

  twoDDoubleFree (coo, 3);

  return;
}

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/GeoUtils/Tess2Geo/Tess2Geo2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"Tess2Geo.h"

void
GeoGenDet (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoVerQty (Tess, pGeo);
  Tess2GeoEdgeQty (Tess, pGeo);
  Tess2GeoFaceQty (Tess, pGeo);
  Tess2GeoPolyQty (Tess, pGeo);

  return;
}

void
GeoAlloc (struct GEO *pGeo)
{
  /*(*pGeo).VerQty    = 0; */
  /*(*pGeo).DummyVerQty       = 0; */
  /*(*pGeo).EdgeQty   = 0; */
  /*(*pGeo).FaceQty   = 0; */
  /*(*pGeo).PolyQty   = 0; */

  (*pGeo).VerCoo = twoDDoubleDAlloc ((*pGeo).VerQty + 1, 3);
  (*pGeo).VerEdgeQty = ut_alloc_1d_int ((*pGeo).VerQty + 1);
  (*pGeo).VerEdgeNb = twoDIntDAlloc ((*pGeo).VerQty + 1, 20);	/* ? */
  (*pGeo).VerBound = twoDIntDAlloc ((*pGeo).VerQty + 1, 4);
  (*pGeo).VerState = ut_alloc_1d_int ((*pGeo).VerQty + 1);	/* ini to 0 */
  (*pGeo).VerLength = oneDDoubleDAlloc ((*pGeo).VerQty + 1);

  (*pGeo).EdgeVerNb = twoDIntDAlloc ((*pGeo).EdgeQty + 1, 2);
  (*pGeo).EdgeFaceQty = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeFaceNb = twoDIntDAlloc ((*pGeo).EdgeQty + 1, 10);
  (*pGeo).EdgeLength = oneDDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeState = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeDel = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodeQty = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodes = oneDpDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNodeCls = oneDpDoubleDAlloc ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeNode1Id = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);
  (*pGeo).EdgeSeg1Id = ut_alloc_1d_int ((*pGeo).EdgeQty + 1);

  (*pGeo).FaceGerm = twoDIntDAlloc ((*pGeo).FaceQty + 1, 2);
  (*pGeo).FaceVerQty = ut_alloc_1d_int ((*pGeo).FaceQty + 1);
  (*pGeo).FaceVerNb = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEdgeNb = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEdgeOri = oneDpIntDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceEq = twoDDoubleDAlloc ((*pGeo).FaceQty + 1, 4);
  (*pGeo).FaceState = ut_alloc_1d_int ((*pGeo).FaceQty + 1);
  (*pGeo).FaceDis = ut_alloc_1d_int ((*pGeo).FaceQty + 1);
  (*pGeo).FacePt = ut_alloc_1d_int ((*pGeo).FaceQty + 1);
  (*pGeo).FacePtCoo = twoDDoubleDAlloc ((*pGeo).FaceQty + 1, 3);
  (*pGeo).FaceFF = oneDDoubleDAlloc ((*pGeo).FaceQty + 1);
  (*pGeo).FaceBound = ut_alloc_1d_int ((*pGeo).FaceQty + 1);

  (*pGeo).PolyFaceQty = ut_alloc_1d_int ((*pGeo).PolyQty + 1);
  (*pGeo).PolyFaceNb = oneDpIntDAlloc ((*pGeo).PolyQty + 1);
  (*pGeo).PolyFaceOri = oneDpIntDAlloc ((*pGeo).PolyQty + 1);

  (*pGeo).FaceNodes = (NODES *) calloc ((*pGeo).FaceQty + 1, sizeof (NODES));
  (*pGeo).FaceM0D = (MESH *) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));
  (*pGeo).FaceM1D = (MESH *) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));
  (*pGeo).FaceM2D = (MESH *) calloc ((*pGeo).FaceQty + 1, sizeof (MESH));

  (*pGeo).DomainSize = twoDDoubleDAlloc (3, 2);

  return;
}

/* Tess2Geotializing the properties of the vertices */
void
Tess2GeoVer (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoVerCoo (Tess, pGeo);
  Tess2GeoVerEdge (Tess, pGeo);
  Tess2GeoVerBound (Tess, pGeo);
  /* now useless */
  /*Tess2GeoVerState(Tess,pGeo); */

  return;
}

/* Tess2Geotializing the properties of the edges */
void
Tess2GeoEdge (struct TESS Tess, struct GEO *pGeo)
{
  /*LineHeader(-1); printf("Tess2GeoEdgeVerNb\n"); */
  Tess2GeoEdgeVerNb (Tess, pGeo);
  /*LineHeader(-1); printf("Tess2GeoEdgeFace\n"); */
  Tess2GeoEdgeFace (Tess, pGeo);
  /*LineHeader(-1); printf("Tess2GeoEdgeLength\n"); */
  Tess2GeoEdgeLength (pGeo);
  /*printf("Tess2GeoEdgeDel\n"); */
  /*Tess2GeoEdgeDel   (Tess,pGeo); */

  return;
}

/* Tess2Geotializing the properties of the faces */
void
Tess2GeoFace (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoFaceGerm (Tess, pGeo);
  Tess2GeoFaceVer (Tess, pGeo);
  Tess2GeoFaceEdge (Tess, pGeo);
  /*Tess2GeoFaceFF  (Tess,pGeo); */
  Tess2GeoFaceEq (Tess, pGeo);
  Tess2GeoFaceBound (pGeo);
  /* now useless */

  return;
}

/* Tess2Geotializing the properties of the polyhedra */
void
Tess2GeoPoly (struct TESS Tess, struct GEO *pGeo)
{
  Tess2GeoPolyFace (Tess, pGeo);

  return;
}

/* Tess2GeoDomainSize ini the domain size */
void
Tess2GeoDomainSize (struct TESS Tess, struct GEO *pGeo)
{
  int i, j;
  double **coo = twoDDoubleDAlloc (3, 8);

  for (i = 0; i < 3; i++)
  {
    for (j = 0; j < 8; j++)
      coo[i][j] = Tess.VerCoo[Tess.VerOfDomain[j]][i];

    /* lower bounds are supposed to be 0, 0, 0. */
    (*pGeo).DomainSize[i][0] = oneDDoubleMin (coo[i], 0, 7);
    (*pGeo).DomainSize[i][1] = oneDDoubleMax (coo[i], 0, 7);
  }

  twoDDoubleFree (coo, 3);

  return;
}
